@@ -1,5 +1,6 @@
 import os.path
 from django.core.mail import EmailMultiAlternatives
+from django.core.urlresolvers import reverse
 from django.template.loader import get_template
 from django.template import Context
 from hunger.utils import setting
@@ -17,7 +18,7 @@ def beta_confirm(email, **kwargs):
 
     templates_folder = setting('BETA_EMAIL_TEMPLATES_DIR', 'hunger')
     templates_folder = os.path.join(templates_folder, '')
-    from_email = setting('EMAIL_HOST_USER')
+    from_email = kwargs.get('from_email', setting("DEFAULT_FROM_EMAIL"))
     if templates_folder == 'hunger':
         file_extension = 'email'
     else:
@@ -26,12 +27,12 @@ def beta_confirm(email, **kwargs):
     context_dict = kwargs.copy()
     if templated_email_available:
         send_templated_mail(
-            template_dir=templates_folder,
             template_name='beta_confirm',
-            file_extension=file_extension,
             from_email=from_email,
             recipient_list=[email],
             context=context_dict,
+            template_dir=templates_folder,
+            file_extension=file_extension,
         )
     else:
         plaintext = get_template(os.path.join(templates_folder, 'beta_confirm.txt'))
@@ -40,23 +41,26 @@ def beta_confirm(email, **kwargs):
         text_content = plaintext.render(Context())
         html_content = html.render(Context())
         msg = EmailMultiAlternatives(subject, text_content, from_email, [to],
-                                     headers={'From': 'Mailer <%s>' % from_email})
+                                     headers={'From': '%s' % from_email})
         msg.attach_alternative(html_content, "text/html")
         msg.send()
 
-def beta_invite(email, code, **kwargs):
+def beta_invite(email, code, request, **kwargs):
     """
     Email for sending out the invitation code to the user.
-    Invitation code is added to the context, so it can be rendered with standard
+    Invitation URL is added to the context, so it can be rendered with standard
     django template engine.
     """
     context_dict = kwargs.copy()
-    context_dict.setdefault('code', code)
+    context_dict.setdefault(
+        "invite_url",
+        request.build_absolute_uri(reverse("beta_verify_invite", args=[code]))
+    )
     context = Context(context_dict)
 
     templates_folder = setting('BETA_EMAIL_TEMPLATES_DIR', 'hunger')
     templates_folder = os.path.join(templates_folder, '')
-    from_email = setting('EMAIL_HOST_USER')
+    from_email = kwargs.get('from_email', setting("DEFAULT_FROM_EMAIL"))
     if templates_folder == 'hunger':
         file_extension = 'email'
     else:
@@ -64,12 +68,12 @@ def beta_invite(email, code, **kwargs):
 
     if templated_email_available:
         send_templated_mail(
-            template_dir=templates_folder,
             template_name='beta_invite',
-            file_extension=file_extension,
             from_email=from_email,
             recipient_list=[email],
             context=context_dict,
+            template_dir=templates_folder,
+            file_extension=file_extension,
         )
     else:
         plaintext = get_template(os.path.join(templates_folder, 'beta_invite.txt'))
@@ -79,6 +83,6 @@ def beta_invite(email, code, **kwargs):
         text_content = plaintext.render(context)
         html_content = html.render(context)
         msg = EmailMultiAlternatives(subject, text_content, from_email, [to],
-                                     headers={'From': 'Mailer <%s>' % from_email})
+                                     headers={'From': '%s' % from_email})
         msg.attach_alternative(html_content, "text/html")
         msg.send()
